/***************************************************
  This is our GFX example for the Adafruit ILI9341 Breakout and Shield
  ----> http://www.adafruit.com/products/1651

  Check out the links above for our tutorials and wiring diagrams
  These displays use SPI to communicate, 4 or 5 pins are required to
  interface (RST is optional)
  Adafruit invests time and resources providing this open source code,
  please support Adafruit and open-source hardware by purchasing
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.
  MIT license, all text above must be included in any redistribution
 ****************************************************

  This is a free software with NO WARRANTY.
  https://simple-circuit.com/

 ****************************************************/

#include <Adafruit_GFX.h>       // include Adafruit graphics library
#include <Adafruit_ILI9341.h>   // include Adafruit ILI9341 TFT library

#define TFT_CS    8      // TFT CS  pin is connected to arduino pin 8
#define TFT_RST   9      // TFT RST pin is connected to arduino pin 9
#define TFT_DC    7    // TFT DC  pin is connected to arduino pin 10
// initialize ILI9341 TFT library
Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC, TFT_RST);
int leftColW = 60;
int rightCol = 260;

#define lcbrown tft.color565(234, 150, 46)
#define lcgold tft.color565(0xff, 0xaa, 0)
#define lcgray tft.color565(78, 75, 71)
#define lcltblue tft.color565(0xbb, 0xbb, 0xff)
#define lcltgreen tft.color565(0x99, 0xaa, 0x66)
#define lcgreen tft.color565(0x0, 0xbb, 0)
#define lcwhite tft.color565(0xfe, 0xeb, 0xde)
#define lcred tft.color565(0xee, 0, 0)
#define lcblack tft.color565(0, 0, 0)
#define lcltpurple tft.color565(0xdd, 0x88, 0xdd)
#define lcblue tft.color565(0xa, 0x4b, 0xee)

void setup() {

  Serial.begin(9600);
  Serial.println("ILI9341 Test!"); 


  tft.begin();



  
  tft.setRotation(3);
  tft.fillScreen(ILI9341_BLACK);
  tft.fillRoundRect(0, 0, 348, 240, 32, lcgold);
  tft.fillRoundRect(60, 16, 340, 210, 12, lcblack);
  
  
  tft.fillRect(245, 0, 55, 30, lcblack);
  tft.setTextSize(2);
  tft.setTextColor(lcltblue);  
  tft.setCursor(250, 2);
  tft.println("WARP");
  
  uint16_t randColor[6] = {lcred,lcgreen,lcgray,lcbrown,lcblue,lcwhite};
  String lcwords[7] = {"NOMINAL","PRESSURE","SPEED","MATTER","ANTIMATT","74-2344","34-6979"};
  
  int w = 0;
  randomSeed(analogRead(A0));
  tft.setTextSize(1);
  tft.setTextColor(lcwhite);  
  for (int n = 60; n <= 180; n+=20){
    tft.drawLine(0, n, 60, n, lcblack);
    tft.fillRect(0, n+1, 60, 20, randColor[random(0,5)]);
    tft.setCursor(6, n + 5);
    tft.println(lcwords[w++]);
  }

  for (int n = 40; n < 108; n+= 22){
    tft.fillRoundRect(120, n, 60, 20, 8, lcblue);
  }
  tft.fillRoundRect(110, 106, 80, 30, 8, lcgray);
  tft.fillRoundRect(136, 118, 30, 5, 2, lcwhite);
  
  for (int n = 138; n < 198; n+= 22){
    tft.fillRoundRect(120, n, 60, 20, 8, lcblue);
  }
}


void loop(void) {




}
